// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************

#ifndef __CONFIG_H__
#define __CONFIG_H__

#define CONFIG(Param)             ( CfgGetpData ()->Param)
#define CONFIG_COLOR(Color)       (*CfgGetpColor(Color))
#define CONFIG_FONT(FontObject)   (*CfgGetpFont (FontObject ))

typedef enum
{
   CFG_STARTUPSIZE_STANDARD,
   CFG_STARTUPSIZE_FULLSCREEN,
   CFG_STARTUPSIZE_MAXIMIZED,
   CFG_STARTUPSIZE_MANUAL,
} t_CfgStartupSize;

typedef enum
{
   CFG_NUMBERSTYLE_LOCALE,
   CFG_NUMBERSTYLE_DECIMAL_COMMA,
   CFG_NUMBERSTYLE_DECIMAL_POINT
} t_CfgNumberStyle;

typedef enum
{
   CFG_ENTRYMODE_HIDE,
   CFG_ENTRYMODE_SHOWDEFAULT,
   CFG_ENTRYMODE_SHOWLAST
} t_CfgEntryMode;

const int CFG_MAX_FONT_FAMILY_LEN   =   63;
const int CFG_MAX_PATH_LEN          = 1024;
const int CFG_MAX_TITLEID_LEN       =   31;
const int CFG_MAX_MENU_NAME_LEN     =  255;
const int CFG_MAX_LANGUAGE_CODE_LEN =    5;
const int CFG_MAX_EWFINFO_LEN       =  255;

class QColor; //lint !e763
class QFont;  //lint !e763

typedef enum
{
   FONTOBJECT_MENU=0,                 // must start with 0, as it is used for addressing an array
   FONTOBJECT_DIALOGDEFAULT,

   FONTOBJECT_COUNT
} t_CfgFontObject;

typedef enum
{
   COLOR_LOCALDEVICES=0,

   COLOR_COUNT,
   COLOR_DEFAULT  // Not really a color, but used for specifying, that a widget should switch to its default color (grey for a button, for instance)
} t_CfgColor;


// ATTENTION: The data of the following structure is filled in by the CFG tool. As this
// one doesn't know about 'bool' (it's written in ANSI C), bool MUST not be used here.
// ------------------------------------------------------------------------------------
#define bool "Do not use bool, take int instead"
typedef struct
{
   t_CfgStartupSize     StartupSize;
   int                  StartupSizeManualX;
   int                  StartupSizeManualY;
   int                  StartupSizeManualDx;
   int                  StartupSizeManualDy;

   t_CfgStartupSize     FileDialogSize;
   int                  FileDialogSizeManualDx;
   int                  FileDialogSizeManualDy;

   t_CfgNumberStyle     NumberStyle;

   int                  ScanUsingDbusHal;
   int                  ScanInterval;
   int                  ScreenRefreshInterval;
   char                 CommandGetSerialNumber[CFG_MAX_PATH_LEN+1];

   int                  EwfFormat;
   int                  EwfCompression;
   int                  EwfSegmentSize;

   t_CfgEntryMode       EntryModeEwfCaseNumber;
   t_CfgEntryMode       EntryModeEwfEvidenceNumber;
   t_CfgEntryMode       EntryModeEwfExaminer;
   t_CfgEntryMode       EntryModeEwfDescription;
   t_CfgEntryMode       EntryModeEwfNotes;
   t_CfgEntryMode       EntryModeImageDirectory;
   t_CfgEntryMode       EntryModeImageFilename;
   t_CfgEntryMode       EntryModeInfoFilename;
   char                 DefaultEwfCaseNumber    [CFG_MAX_EWFINFO_LEN+1];
   char                 DefaultEwfEvidenceNumber[CFG_MAX_EWFINFO_LEN+1];
   char                 DefaultEwfExaminer      [CFG_MAX_EWFINFO_LEN+1];
   char                 DefaultEwfDescription   [CFG_MAX_EWFINFO_LEN+1];
   char                 DefaultEwfNotes         [CFG_MAX_EWFINFO_LEN+1];
   char                 DefaultImageDirectory   [CFG_MAX_PATH_LEN   +1];
   char                 DefaultImageFilename    [CFG_MAX_PATH_LEN   +1];
   char                 DefaultInfoFilename     [CFG_MAX_PATH_LEN   +1];

   int                  FifoBlockSize;
   int                  FifoMaxBlocks;
   int                  UseSeparateThreadForMD5;
   int                  CompressionThreads;
   int                  SignalHandling;
   int                  WriteToDevNull;
   int                  UseMemWatch;
   int                  VerboseLibewf;
} t_CfgData, *t_pCfgData;
#undef bool


typedef struct
{
   char      Code      [CFG_MAX_LANGUAGE_CODE_LEN+1];
   char      AsciiName [CFG_MAX_MENU_NAME_LEN    +1];
} t_CfgBuffLanguage, *t_pCfgBuffLanguage;

typedef struct
{
   t_CfgFontObject Object;
   char            Family[CFG_MAX_FONT_FAMILY_LEN+1];
   int             Size;
   int             Weight;
   int             Italic;
} t_CfgBuffFont, *t_pCfgBuffFont;

typedef struct
{
   t_CfgColor Color;
   int        R;
   int        G;
   int        B;
} t_CfgBuffColor, *t_pCfgBuffColor;

typedef struct
{
   char Device [CFG_MAX_PATH_LEN+1];
} t_CfgBuffLocalDevice, *t_pCfgBuffLocalDevice;

typedef struct
{
   char Command [CFG_MAX_PATH_LEN+1];
} t_CfgBuffDeviceInfoCommand, *t_pCfgBuffDeviceInfoCommand;

QFont        *CfgGetpFont    (t_CfgFontObject Object);
const QColor *CfgGetpColor   (t_CfgColor      Color );
APIRET CfgGetLocalDevices       (QStringList **ppLocalDevices);
APIRET CfgGetDeviceInfoCommands (QStringList **ppDeviceInfoCommands);


APIRET CfgInit        (void);
APIRET CfgDeInit      (void);

t_pCfgData CfgGetpData(void);

APIRET CfgGetLogFileName    (t_pcchar *ppLogFileName, bool *pDefaultUsed);
APIRET CfgGetCfgFileName    (t_pcchar *ppCfgFileName, bool *pDefaultUsed);
APIRET CfgReadConfiguration (t_pcchar   pCfgFileName);

APIRET ConfigTranslateUnicodeEscape (char *pSrc, QString *pDest);

void CfgFontPrint (void);

// ------------------------------------
//             Error codes
// ------------------------------------

enum
{
   ERROR_CFG_ONLY_TEMPLATE_GENERATED = ERROR_BASE_CFG + 1,
};


#endif

