// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         Acquisition dialog
// ****************************************************************************

#include <QtGui>

#include "common.h"
#include "compileinfo.h"
#include "config.h"
#include "qtutil.h"
#include "dlgdirsel.h"
#include "dlgacquire.h"

// -----------------------------
//           Constants
// -----------------------------

const char *DLG_ACQUIRE_DEFAULT_EMPTY_FILENAME = "Out";  // Default image file name if - after removing special chars - the file name is empty.

// -----------------------------
//           Classes
// -----------------------------

class t_DlgAcquireLocal
{
   public:
      QRadioButton    *pRadioButtonFormatEWF;
      QRadioButton    *pRadioButtonFormatDD;

      QList<QWidget*>   EwfWidgetsList;   // Used zo comfortably enable / disable EWF related entry fields and labels

      QLineEdit       *pEntryCaseNr;
      QLineEdit       *pEntryEvidenceNr;
      QLineEdit       *pEntryExaminer;
      QLineEdit       *pEntryDescription;
      QLineEdit       *pEntryNotes;

      QLabel          *pLabelFolder;
      QLineEdit       *pEntryImageFilename;
      QLineEdit       *pEntryInfoFilename;

      QCheckBox       *pCheckBoxCalcMD5;
      QCheckBox       *pCheckBoxVerifyMD5;

      QPushButton     *pButtonOk;
      QPushButton     *pButtonCancel;

      QFileDialog     *pDlg;


      static QString    LastEnteredCaseNumber;
      static QString    LastEnteredEvidenceNumber;
      static QString    LastEnteredExaminer;
      static QString    LastEnteredDescription;
      static QString    LastEnteredNotes;
      static QString    LastEnteredPath;
      static QString    LastEnteredImageFilename;
      static QString    LastEnteredInfoFilename;
};

QString t_DlgAcquireLocal::LastEnteredCaseNumber    = QString();
QString t_DlgAcquireLocal::LastEnteredEvidenceNumber= QString();
QString t_DlgAcquireLocal::LastEnteredExaminer      = QString();
QString t_DlgAcquireLocal::LastEnteredDescription   = QString();
QString t_DlgAcquireLocal::LastEnteredNotes         = QString();
QString t_DlgAcquireLocal::LastEnteredPath          = QString();
QString t_DlgAcquireLocal::LastEnteredImageFilename = QString();
QString t_DlgAcquireLocal::LastEnteredInfoFilename  = QString();


static APIRET DlgAcquireGetFieldValue (t_pDevice pDevice, t_CfgEntryMode EntryMode, const QString &Default, const QString &LastEntry, QString &Set)
{
   if ((EntryMode == CFG_ENTRYMODE_SHOWLAST) && (!LastEntry.isNull()))
   {
      Set = LastEntry;
   }
   else
   {
      Set = Default;
      QDateTime Now = QDateTime::currentDateTime();

      Set.replace ("%d%"   , Now.toString("d"   ));  // Special sequences
      Set.replace ("%dd%"  , Now.toString("dd"  ));
      Set.replace ("%ddd%" , Now.toString("ddd" ));
      Set.replace ("%dddd%", Now.toString("dddd"));
      Set.replace ("%M%"   , Now.toString("M"   ));
      Set.replace ("%MM%"  , Now.toString("MM"  ));
      Set.replace ("%MMM%" , Now.toString("MMM" ));
      Set.replace ("%MMMM%", Now.toString("MMMM"));
      Set.replace ("%yy%"  , Now.toString("yy"  ));
      Set.replace ("%yyyy%", Now.toString("yyyy"));
      Set.replace ("%h%"   , Now.toString("h"   ));
      Set.replace ("%hh%"  , Now.toString("hh"  ));
      Set.replace ("%m%"   , Now.toString("m"   ));
      Set.replace ("%mm%"  , Now.toString("mm"  ));
      Set.replace ("%s%"   , Now.toString("s"   ));
      Set.replace ("%ss%"  , Now.toString("ss"  ));
      Set.replace ("%AP%"  , Now.toString("AP"  ));
      Set.replace ("%ap%"  , Now.toString("ap"  ));

      QVariant SizeHuman = t_Device::GetSizeHuman (pDevice);
      Set.replace ("%serial%" , pDevice->SerialNumber);
      Set.replace ("%model%"  , pDevice->Model       );
      Set.replace ("%size%"   , SizeHuman.toString() );
      Set.replace ("%version%", pCompileInfoVersion  );
   }

   return NO_ERROR;
}

t_DlgAcquire::t_DlgAcquire ()
{
   CHK_EXIT (ERROR_DLGACQUIRE_CONSTRUCTOR_NOT_SUPPORTED)
} //lint !e1401 pOwn not initialised

t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, QWidget *pParent, Qt::WFlags Flags)
   :QDialog (pParent, Flags)
{
   static bool   Initialised = false;
   QVBoxLayout *pLayout;
   QString       DefaultFilename;
   QString       Path;
   QString       Str;
   QString       ButtonTextEWF;
   QString       ButtonTextDD;
   QString       Set;
   QLabel      *pLabel;
   int           Row = 0;

   if (!Initialised)
   {
      Initialised = true;
      CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_DLGACQUIRE_CONSTRUCTOR_NOT_SUPPORTED))
      CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_DLGACQUIRE_UNKNOWN_FILEDIALOG_SIZE))
   }

   setWindowTitle (tr ("Acquisition parameters"));
   pOwn    = new t_DlgAcquireLocal;
   pLayout = new QVBoxLayout (this);
   setLayout (pLayout);

   pLayout->addWidget (new QLabel(("<b>" + tr("Acquisition parameters for %1") + "</b>") .arg(pDevice->LinuxDevice) , this));

   // Format
   // ------
   QGroupBox   *pGroupBoxFormat = new QGroupBox (tr("File format"), this);
   QVBoxLayout *pLayoutFormat   = new QVBoxLayout;
   QGridLayout *pLayoutEwf      = new QGridLayout ();

   pGroupBoxFormat->setLayout (pLayoutFormat);
   pLayout->addWidget (pGroupBoxFormat);
   pLayout->addStretch (1);

   CHK_EXIT (t_File::GetFormatDescription (t_File::EWF, Str))            ButtonTextEWF = "&" + Str;
   CHK_EXIT (t_File::GetFormatDescription (t_File::DD , Str))            ButtonTextDD  = "&" + Str;
   CHK_EXIT (t_File::GetFormatExtension   (t_File::EWF, NULL, &Str))     ButtonTextEWF+= tr(" (file extension %1)") .arg (Str);
   CHK_EXIT (t_File::GetFormatExtension   (t_File::DD , NULL, &Str))     ButtonTextDD += tr(" (file extension %1)") .arg (Str);

   pOwn->pRadioButtonFormatEWF = new QRadioButton (ButtonTextEWF, this);
   pOwn->pRadioButtonFormatDD  = new QRadioButton (ButtonTextDD , this);

   pLayoutFormat->addWidget  (pOwn->pRadioButtonFormatDD );
   pLayoutFormat->addWidget  (pOwn->pRadioButtonFormatEWF);
   pLayoutFormat->addLayout  (pLayoutEwf);

   #define ADD_EWF_FIELD(LabelName, pEntry, EntryMode) \
      pLabel = new QLabel    (LabelName, this);        \
      pEntry = new QLineEdit (this);                   \
      if (EntryMode == CFG_ENTRYMODE_HIDE)             \
      {                                                \
         pLabel->hide();                               \
         pEntry->hide();                               \
      }                                                \
      else                                             \
      {                                                \
         pLayoutEwf->addWidget (pLabel, Row, 1);       \
         pLayoutEwf->addWidget (pEntry, Row, 2);       \
         pOwn->EwfWidgetsList.append (pLabel);         \
         pOwn->EwfWidgetsList.append (pEntry);         \
      }                                                \
      Row++;

   //lint -save -e423  Creation of memory leak in assignment to 'pLabel'
   ADD_EWF_FIELD (tr("Case number"    ), pOwn->pEntryCaseNr     , CONFIG (EntryModeEwfCaseNumber    ))
   ADD_EWF_FIELD (tr("Evidence number"), pOwn->pEntryEvidenceNr , CONFIG (EntryModeEwfEvidenceNumber))
   ADD_EWF_FIELD (tr("Examiner"       ), pOwn->pEntryExaminer   , CONFIG (EntryModeEwfExaminer      ))
   ADD_EWF_FIELD (tr("Description"    ), pOwn->pEntryDescription, CONFIG (EntryModeEwfDescription   ))
   ADD_EWF_FIELD (tr("Notes"          ), pOwn->pEntryNotes      , CONFIG (EntryModeEwfNotes         ))
   #undef ADD_EWF_FIELD

   pLayoutEwf->setColumnMinimumWidth (0, 20);

   // Files
   // -----
   QGroupBox   *pGroupBoxFiles = new QGroupBox(tr("Destination"), this);
   QGridLayout *pLayoutFiles   = new QGridLayout ();
   pGroupBoxFiles->setLayout (pLayoutFiles);
   pLayout->addWidget (pGroupBoxFiles);
   pLayout->addStretch (1);

   Row = 0;
   if (CONFIG(WriteToDevNull))
   {
      pLabel = new QLabel(tr("Configuration flag WriteToDevNull is set!"), this);
      pLayoutFiles->addWidget (pLabel, Row++, 0);
   }
   //lint -restore
   pLayoutFiles->addWidget (new QLabel(tr("Destination folder"                ), this), Row++, 0);
   pLayoutFiles->addWidget (new QLabel(tr("Image filename (without extension)"), this), Row++, 0);
   pLayoutFiles->addWidget (new QLabel(tr("Info filename (without extension)" ), this), Row++, 0);

   if (CONFIG(WriteToDevNull))
        Row = 1;
   else Row = 0;
   QPushButton *pButtonBrowse = new QPushButton (tr("Browse..."), this);
   pLayoutFiles->addWidget (pButtonBrowse, Row, 2);

   pOwn->pLabelFolder        = new QLabel    (this);
   pOwn->pEntryImageFilename = new QLineEdit (this);
   pOwn->pEntryInfoFilename  = new QLineEdit (this);

   pLayoutFiles->addWidget (pOwn->pLabelFolder       , Row++, 1);
   pLayoutFiles->addWidget (pOwn->pEntryImageFilename, Row++, 1, 1, 2);
   pLayoutFiles->addWidget (pOwn->pEntryInfoFilename , Row++, 1, 1, 2);


   // Hash
   // ----
   QGroupBox   *pGroupBoxHash = new QGroupBox(tr("Hash computation"), this);
   QGridLayout *pLayoutHash   = new QGridLayout ();
   pGroupBoxHash->setLayout (pLayoutHash);
   pLayout->addWidget (pGroupBoxHash);
   pLayout->addStretch (1);

   pOwn->pCheckBoxCalcMD5   = new QCheckBox (tr("Calculate MD5 hash"), this);
   pOwn->pCheckBoxVerifyMD5 = new QCheckBox (tr("Verify MD5 hash (not implemented yet)"   ), this);
   pLayoutHash->addWidget (pOwn->pCheckBoxCalcMD5  , 0, 0);
   pLayoutHash->addWidget (pOwn->pCheckBoxVerifyMD5, 1, 0);

   // Dialog buttons
   // --------------

   QHBoxLayout *pLayoutButtons = new QHBoxLayout ();
   pLayout->addLayout (pLayoutButtons);

   pOwn->pButtonOk     = new QPushButton (tr("Ok"    ), this);
   pOwn->pButtonCancel = new QPushButton (tr("Cancel"), this);
   pLayoutButtons->addWidget (pOwn->pButtonOk    );
   pLayoutButtons->addWidget (pOwn->pButtonCancel);
   pOwn->pButtonOk->setDefault (true);

   // Set default values
   // ------------------
   pOwn->pRadioButtonFormatEWF->setChecked (true);
   pOwn->pCheckBoxCalcMD5     ->setChecked (true);

   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeEwfCaseNumber    ), CONFIG (DefaultEwfCaseNumber    ), t_DlgAcquireLocal::LastEnteredCaseNumber    , Set)) pOwn->pEntryCaseNr     ->setText (Set);
   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeEwfEvidenceNumber), CONFIG (DefaultEwfEvidenceNumber), t_DlgAcquireLocal::LastEnteredEvidenceNumber, Set)) pOwn->pEntryEvidenceNr ->setText (Set);
   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeEwfExaminer      ), CONFIG (DefaultEwfExaminer      ), t_DlgAcquireLocal::LastEnteredExaminer      , Set)) pOwn->pEntryExaminer   ->setText (Set);
   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeEwfDescription   ), CONFIG (DefaultEwfDescription   ), t_DlgAcquireLocal::LastEnteredDescription   , Set)) pOwn->pEntryDescription->setText (Set);
   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeEwfNotes         ), CONFIG (DefaultEwfNotes         ), t_DlgAcquireLocal::LastEnteredNotes         , Set)) pOwn->pEntryNotes      ->setText (Set);
   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeImageDirectory   ), CONFIG (DefaultImageDirectory   ), t_DlgAcquireLocal::LastEnteredPath          , Set))
   if (!Set.endsWith ("/"))
      Set += "/";

   pOwn->pLabelFolder->setText (Set);

   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeImageFilename    ), CONFIG (DefaultImageFilename    ), t_DlgAcquireLocal::LastEnteredImageFilename , Set))
   pOwn->pEntryImageFilename->setText (Set);

   CHK_EXIT (DlgAcquireGetFieldValue (pDevice, CONFIG (EntryModeInfoFilename     ), CONFIG (DefaultInfoFilename     ), t_DlgAcquireLocal::LastEnteredInfoFilename  , Set))
   pOwn->pEntryInfoFilename->setText (Set);

   UpdateCheckboxState (pOwn->pCheckBoxCalcMD5->isChecked() ? Qt::Checked : Qt::Unchecked);
   UpdateButtonState   ();

   // Connections
   // -----------
   CHK_QT_EXIT (connect (pOwn->pCheckBoxCalcMD5, SIGNAL (stateChanged(int)), this, SLOT(UpdateCheckboxState(int))))

   CHK_QT_EXIT (connect (pOwn->pEntryImageFilename  , SIGNAL (textChanged(const QString &)), this, SLOT(UpdateButtonState(const QString &))))
   CHK_QT_EXIT (connect (pOwn->pEntryInfoFilename   , SIGNAL (textChanged(const QString &)), this, SLOT(UpdateButtonState(const QString &))))

   CHK_QT_EXIT (connect (pOwn->pRadioButtonFormatDD , SIGNAL (released()), this, SLOT(UpdateFieldState())))
   CHK_QT_EXIT (connect (pOwn->pRadioButtonFormatEWF, SIGNAL (released()), this, SLOT(UpdateFieldState())))

   CHK_QT_EXIT (connect (pOwn->pEntryImageFilename, SIGNAL (editingFinished())           , this, SLOT(UpdateFileName   ()               )))

   CHK_QT_EXIT (connect (pButtonBrowse      , SIGNAL (released()), this, SLOT(SlotBrowse())))
   CHK_QT_EXIT (connect (pOwn->pButtonOk    , SIGNAL (released()), this, SLOT(SlotAccept())))
   CHK_QT_EXIT (connect (pOwn->pButtonCancel, SIGNAL (released()), this, SLOT(reject    ())))
}

void t_DlgAcquire::UpdateCheckboxState (int State)
{
   pOwn->pCheckBoxVerifyMD5->setEnabled (State == Qt::Checked);
}

void t_DlgAcquire::UpdateButtonState (const QString & /*NewText*/)
{
   bool Enabled;

   Enabled = !pOwn->pLabelFolder       ->text().isEmpty() &&
             !pOwn->pEntryImageFilename->text().isEmpty() &&
             !pOwn->pEntryInfoFilename ->text().isEmpty();
   pOwn->pButtonOk->setEnabled (Enabled);
}

void t_DlgAcquire::UpdateFieldState (void)
{
   QWidget *pWidget;
   bool      Enabled;
   int       i;

   Enabled = pOwn->pRadioButtonFormatEWF->isChecked();

   for (i = 0;
        i < pOwn->EwfWidgetsList.count();
        i++)
   {
      pWidget = pOwn->EwfWidgetsList.at(i);
      pWidget->setEnabled (Enabled);
   }
}

void t_DlgAcquire::UpdateFileName (void)
{
   pOwn->pEntryInfoFilename->setText (pOwn->pEntryImageFilename->text());
}

//void t_DlgAcquire::SlotBrowse (void)
//{
//   QFileDialog *pDlg;
//   QString       Path;
//
//   pOwn->pDlg = new QFileDialog (this, tr("Select destination directory"), pOwn->pLabelFolder->text());
//   pDlg = pOwn->pDlg;
//   pDlg->setViewMode (QFileDialog::Detail);
////   pDlg->setFileMode (QFileDialog::Directory);
////   pDlg->setFileMode (QFileDialog::ExistingFiles);
//   pDlg->setAcceptMode (QFileDialog::AcceptSave);
//   pDlg->setConfirmOverwrite (false);
//   pDlg->setLabelText (QFileDialog::Accept, tr("Use this directory"));
//
//   CHK_QT_EXIT (connect (pDlg, SIGNAL(directoryEntered (const QString &)), this, SLOT(SlotDirChanged(const QString &))))
//
//   switch (CONFIG(FileDialogSize))
//   {
//      case CFG_STARTUPSIZE_STANDARD  :                         break;
//      case CFG_STARTUPSIZE_FULLSCREEN: pDlg->showFullScreen(); break;
//      case CFG_STARTUPSIZE_MAXIMIZED : pDlg->showMaximized (); break;
//      case CFG_STARTUPSIZE_MANUAL    : CHK_EXIT (QtUtilSetGeometryCentered (pDlg, CONFIG(FileDialogSizeManualDx), CONFIG(FileDialogSizeManualDy))); break;
//      default                        : CHK_EXIT (ERROR_DLGACQUIRE_UNKNOWN_FILEDIALOG_SIZE)
//   }
//
//   if (pDlg->exec() == QDialog::Accepted)
//   {
//      Path = pDlg->directory().absolutePath();
//      if (!Path.endsWith ("/"))
//         Path += "/";
//   }
////
//   pOwn->pLabelFolder->setText(Path);
//   delete pDlg;
//}


void t_DlgAcquire::SlotDirChanged (const QString &/*NewDir*/)
{
   pOwn->pDlg->selectFile ("abc");
}

//void t_DlgAcquire::SlotBrowse (void)
//{
//   QString Path = QFileDialog::getExistingDirectory(this, tr("Open Directory"), "/", QFileDialog::ShowDirsOnly);
//
//   if (!Path.endsWith ("/"))
//         Path += "/";
//   pOwn->pLabelFolder->setText(Path);
//}

void t_DlgAcquire::SlotBrowse (void)
{
   QString     Path = pOwn->pLabelFolder->text();
   t_DlgDirSel Dlg (&Path, this);

   switch (CONFIG(FileDialogSize))
   {
      case CFG_STARTUPSIZE_STANDARD  :                       break;
      case CFG_STARTUPSIZE_FULLSCREEN: Dlg.showFullScreen(); break;
      case CFG_STARTUPSIZE_MAXIMIZED : Dlg.showMaximized (); break;
      case CFG_STARTUPSIZE_MANUAL    : CHK_EXIT (QtUtilSetGeometryCentered (&Dlg, CONFIG(FileDialogSizeManualDx), CONFIG(FileDialogSizeManualDy))); break;
      default                        : CHK_EXIT (ERROR_DLGACQUIRE_UNKNOWN_FILEDIALOG_SIZE)
   }

   if (Dlg.exec() == QDialog::Accepted)
   {
      if (!Path.endsWith ("/"))
         Path += "/";
      pOwn->pLabelFolder->setText(Path);
   }
}

static APIRET DlgAcquireCheckFilename (const QString &In, bool &Clean, QString &Out)
{
   unsigned char Ch;
   int           i;
   bool          Ok;

   Clean = true;
   Out   = "";
   for (i=0; i<In.length(); i++)
   {
      Ch = In[i].toAscii();
      Ok = ((Ch >= '0') && (Ch <= '9')) ||
           ((Ch >= 'a') && (Ch <= 'z')) ||
           ((Ch >= 'A') && (Ch <= 'Z')) ||
            (Ch == '_');
      if (Ok)
           Out += Ch;
      else Clean = false;
   }
   if (Out.isEmpty())
      Out = DLG_ACQUIRE_DEFAULT_EMPTY_FILENAME;

   return NO_ERROR;
}

void t_DlgAcquire::SlotAccept (void)
{
   QMessageBox::StandardButton  Button;
   QString                      ImageFilenameCorrected;
   QString                      InfoFilenameCorrected;
   bool                         ImageFilenameClean;
   bool                         InfoFilenameClean;

   CHK_EXIT (DlgAcquireCheckFilename (pOwn->pEntryImageFilename->text(), ImageFilenameClean, ImageFilenameCorrected))
   CHK_EXIT (DlgAcquireCheckFilename (pOwn->pEntryInfoFilename ->text(), InfoFilenameClean,  InfoFilenameCorrected ))

   if (ImageFilenameClean && InfoFilenameClean)
   {
      accept();
   }
   else
   {
      LOG_INFO ("Unallowed characters in filenames found")
      Button = QMessageBox::question (this, tr ("Special characters"),
                                            tr ("The filenames contain special characters which are not allowed. Guymager suggests the "
                                                "following changes:"
                                                "\n\tImage filename: %1"
                                                "\n\tInfo filename: %2"
                                                "\nDo you accept these changes?") .arg(ImageFilenameCorrected) .arg(InfoFilenameCorrected),
                                                QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
      if (Button == QMessageBox::Yes)
      {
         LOG_INFO ("User accepts filename changes")
         pOwn->pEntryImageFilename->setText(ImageFilenameCorrected);
         pOwn->pEntryInfoFilename ->setText(InfoFilenameCorrected );
         accept();
      }
      else
      {
         LOG_INFO ("User rejects filename changes")
      }
   }
}

APIRET t_DlgAcquire::GetParameters (t_Device::t_Acquisition &Acquisition)
{
   Acquisition.Path          = pOwn->pLabelFolder         ->text();
   Acquisition.ImageFilename = pOwn->pEntryImageFilename  ->text();
   Acquisition.InfoFilename  = pOwn->pEntryInfoFilename   ->text();
   Acquisition.CalcMD5       = pOwn->pCheckBoxCalcMD5     ->isChecked();
   Acquisition.VerifyMD5     = pOwn->pCheckBoxVerifyMD5   ->isChecked();
   Acquisition.Format        = pOwn->pRadioButtonFormatEWF->isChecked() ? t_File::EWF : t_File::DD;
   Acquisition.CaseNumber    = pOwn->pEntryCaseNr         ->text();
   Acquisition.EvidenceNumber= pOwn->pEntryEvidenceNr     ->text();
   Acquisition.Examiner      = pOwn->pEntryExaminer       ->text();
   Acquisition.Description   = pOwn->pEntryDescription    ->text();
   Acquisition.Notes         = pOwn->pEntryNotes          ->text();

   t_DlgAcquireLocal::LastEnteredCaseNumber     = Acquisition.CaseNumber;
   t_DlgAcquireLocal::LastEnteredEvidenceNumber = Acquisition.EvidenceNumber;
   t_DlgAcquireLocal::LastEnteredExaminer       = Acquisition.Examiner;
   t_DlgAcquireLocal::LastEnteredDescription    = Acquisition.Description;
   t_DlgAcquireLocal::LastEnteredNotes          = Acquisition.Notes;
   t_DlgAcquireLocal::LastEnteredPath           = Acquisition.Path;
   t_DlgAcquireLocal::LastEnteredImageFilename  = Acquisition.ImageFilename;
   t_DlgAcquireLocal::LastEnteredInfoFilename   = Acquisition.InfoFilename;

   return NO_ERROR;
}

t_DlgAcquire::~t_DlgAcquire ()
{
   delete pOwn;
}

